# Crossability verification: Fish ladders

When verifying a fish ladder, basins and walls are sequentially tested, as well as every device of each wall. If at least one basin is not crossable, then the pass is not crossable.

Criteria differ depending on the jet type generated by the device being verified. If a wall has several devices, it will be considered crossable if at least one device is crossable.

Orifices are considered uncrossable.

## Criteria

### Diving jet support

Some species do not support diving jets. For such species, each device leading to a diving jet is marked as not crossable.

### Maximum fall \(DHMaxS\) and \(DHMaxP\), in m

Basin fall \(DH\) must be lower than maximum fall.

### Minimum slot width \(BMin\), in m (surface jet only)

Slot width \(L\) must be greater than minimum width. For orifices, surface \(S\) must be greater than minimum width squared.

### Minimum head on weir \(HMin\), in m

Head \(h1\) on weir must be greater than minimum head.

### Minimum basin depth \(PMinS\) and \(PMinP\), in m

Basin depth \(YMOY\) must be greater than minimum depth. For diving jets, depth must be greater than twice the basin fall \(DH\).

### Minimum basin length \(LMinS\) and \(LMinP\), in m

Basin length \(LB\) must be greater than minimum length.

### Recommanded maximum dissipated power \(PVMaxPrec\) and limit maximum dissipated power \(PVMaxLim\), in W/m³

Maximal dissipated power \(PVMax\) in the basin must be lower than limit maximum dissipated power. If it is greater than recommanded maximum dissipated power, a warning is thrown.

**Important:** maximum dissipated power verification is **disabled** in the current Cassiopée version.

## Criteria values for predefined species groups

From _"Informations sur la Continuité Écologique - ICE, Onema 2014"_, and D. Courret.

### Common values for surface jet and diving jet

| ICE group | Species | Minimum head on weir (m) | Recommanded maximum dissipated power (W/m³) | Limit maximum dissipated power (W/m³) |
|------------|---------|---------|---------|---------|
| 1 | Atlantic salmon (Salmo salar)<br>Sea or river trout [50-100] (Salmo trutta) | 0.3 | 200 | 250 |
| 2 | Mules (Chelon labrosus, Liza ramada) | 0.2 | 200 | 250 |
| 3a | Gread shad (Alosa alosa) | 0.4 | 150 | 200 |
| 3b | Shad (Alosa fallax fallax) | 0.4 | 150 | 200 |
| 3c | Sea lamprey (Petromyzon marinus) | 0.15 | 200 | 250 |
| 4a | River trout or sea trout [25-55] (Salmo trutta) | 0.2 | 200 | 250 |
| 4b | River trout [15-30] (Salmo trutta) |0.2 | 200 | 250 |
| 5 | Aspe (Aspius aspius)<br>Pike (Esox lucius) | 0.2 | 150 | 200 |
| 6 | Common grayling (Thymallus thymallus) | 0.2 | 200 | 250 |
| 7a | Common barbel (Barbus barbus)<br>Chub (Squalius cephalus)<br>Nase (Chondrostoma nasus) | 0.2 | 150 | 200 |
| 7b | River lamprey (Lampetra fluviatilis) | 0.15 | 130 | 150 |
| 8a | Common carp (Cyprinus carpio) | 0.2 | - | - |
| 8b | Common bream (Abramis brama)<br>Pike-perch (Sander lucioperca) | 0.2 | 150 | 200 |
| 8c | White bream (Blicca bjoerkna)<br>Ide (Leuciscus idus)<br>Burbot (Lota lota)<br>Perch (Perca fluviatilis)<br>Tench (Tinca tinca) | 0.2 | 130 | 150 |
| 8d | Common dace (Leuciscus sp but Idus) | 0.2 | 150 | 200 |
| 9a | Bleak (Alburnus alburnus)<br>Sprirlin (Alburnoides bipunctatus)<br>Mediterranean barbel (Barbus meridionalis)<br>Souffia (Telestes souffia)<br>Crucian carp (Carassius carassius)<br>Prussian carp (Carassius gibelio)<br>Roach (Rutilus rutilus)<br>Common rudd (Scardinius erythrophthalmus)<br>South-west european nase (Parachondrostoma toxostoma) | 0.2 | 130 | 150 |
| 9b | Apron (Zingel asper)<br>Cottus sp<br>Gobio sp<br>Ruffe (Gymnocephalus cernuus)<br>Brook lamprey (Lampetra planeri)<br>Stone loach ( Barbatula barbatula)<br>Spined loach (Cobitis taenia) | 0.2 | 130 | 150 |
| 10 | Sunbleak (Leucaspius delineatus)<br>European bitterling (Rhodeus amarus)<br>Three-spined stickleback (Gasterosteus gymnurus)<br>Ninespine stickleback (Pungitius laevis)<br>Minnows (Phoxinus sp) | 0.2 | 100 | 150 |

Table: List of predefined values for crossing criteria of a fish ladder

### Surface jet

| ICE group | Species | Maximum fall (m) | Minimum slot width (m) | Minimum basin depth (m) | Minimum basin length (m) |
|------------|---------|---------|---------|--------------|----------|
| 1 | Atlantic salmon (Salmo salar)<br>Sea or river trout [50-100] (Salmo trutta) | 0.35 | 0.3 | 1 | 2.5 |
| 2 | Mules (Chelon labrosus, Liza ramada) | 0.35 | 0.2 | 1 | 1.75 |
| 3a | Gread shad (Alosa alosa) | 0.3 | 0.4 | 1 | 3.5 |
| 3b | Shad (Alosa fallax fallax) | 0.3 |  0.4 | 1 | 3.5 |
| 3c | Sea lamprey (Petromyzon marinus) | 0.3 |  0.15 | 1 | 1.25 |
| 4a | River trout or sea trout [25-55] (Salmo trutta) | 0.35 | 0.2 | 1 | 1.75 |
| 4b | River trout [15-30] (Salmo trutta) | 0.3 | 0.15 | 0.75 | 1.75 |
| 5 | Aspe (Aspius aspius)<br>Pike (Esox lucius) | 0.3  | 0.3 | 0.75 | 2.5 |
| 6 | Common grayling (Thymallus thymallus) | 0.3 | 0.2 | 0.75 | 1.75 |
| 7a | Common barbel (Barbus barbus)<br>Chub (Squalius cephalus)<br>Nase (Chondrostoma nasus) | 0.3 | 0.25 | 0.75 | 2 |
| 7b | River lamprey (Lampetra fluviatilis) | 0.3 | 0.15 | 0.75 | 1.25 |
| 8a | Common carp (Cyprinus carpio) | 0.25 | 0.3 | 0.75 | 2.5 |
| 8b | Common bream (Abramis brama)<br>Pike-perch (Sander lucioperca) | 0.25 | 0.3 | 0.75 | 2.5 |
| 8c | White bream (Blicca bjoerkna)<br>Ide (Leuciscus idus)<br>Burbot (Lota lota)<br>Perch (Perca fluviatilis)<br>Tench (Tinca tinca) | 0.25 | 0.3 | 0.75 | 2.5 |
| 8d | Common dace (Leuciscus sp but Idus) | 0.25 | 0.3 | 0.75 | 2.5 |
| 9a | Bleak (Alburnus alburnus)<br>Sprirlin (Alburnoides bipunctatus)<br>Mediterranean barbel (Barbus meridionalis)<br>Souffia (Telestes souffia)<br>Crucian carp (Carassius carassius)<br>Prussian carp (Carassius gibelio)<br>Roach (Rutilus rutilus)<br>Common rudd (Scardinius erythrophthalmus)<br>South-west european nase (Parachondrostoma toxostoma) | 0.25 | 0.25 | 0.75 | 2 |
| 9b | Apron (Zingel asper)<br>Cottus sp<br>Gobio sp<br>Ruffe (Gymnocephalus cernuus)<br>Brook lamprey (Lampetra planeri)<br>Stone loach ( Barbatula barbatula)<br>Spined loach (Cobitis taenia) | 0.2 | 0.15 | 0.5 | 1.25 |
| 10 | Sunbleak (Leucaspius delineatus)<br>European bitterling (Rhodeus amarus)<br>Three-spined stickleback (Gasterosteus gymnurus)<br>Ninespine stickleback (Pungitius laevis)<br>Minnows (Phoxinus sp) | 0.2 | 0.15 | 0.5 | 1.25 |

Table: List of predefined values for crossing criteria of a fish ladder, with surface jet

### Diving jet

| ICE Group | Species | Maximum fall (m) | Minimum basin depth (m) | Minimum basin length (m) |
|------------|---------|---------|-----------|--------------|
| 1 | Atlantic salmon (Salmo salar)<br>Sea or river trout [50-100] (Salmo trutta) | 0.75 | 1 | 2 |
| 2 | Mules (Chelon labrosus, Liza ramada) | 0.6 | 0.75 | 1.25 |
| 4a | River trout or sea trout [25-55] (Salmo trutta) | 0.4 | 0.75 | 1.25 |
| 4b | River trout [15-30] (Salmo trutta) | 0.3 | 0.75 | 1 |
| 6 | Common grayling (Thymallus thymallus) | 0.3 | 0.75 | 1 |

Table: List of predefined values for crossing criteria of a fish ladder, with diving jet
